package guest;
 
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.TypedQuery;
import javax.persistence.metamodel.ManagedType;

import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;

	
@Stateless
@TransactionManagement(TransactionManagementType.CONTAINER)
@TransactionAttribute(TransactionAttributeType.REQUIRED)
public class GuestDao {
    // Injected database connection:
	@PersistenceContext(unitName = "guest-pu") private EntityManager em;

    // Stores a new guest
    public void persist(final Guest guest) {
		Guest persistedGuest = findByName( guest.getName() );
		if ( persistedGuest == null ) {
			this.em.persist(guest);
		}
    }
	
    // Retrieves all the guests:
	public List<Guest> findAll() {
	
		final TypedQuery<Guest> query = this.em.createNamedQuery( "Guest.findAll", Guest.class );
		final List<Guest> guests =  query.getResultList();
		return guests;
    }
	
	public Guest findByName( final String name ) {
		Guest guest = null;
		if ( name != null ) {
			TypedQuery<Guest> query = this.em.createNamedQuery( "Guest.findByName", Guest.class )
				.setParameter( "name", name.toLowerCase() );
			final List<Guest> guests =  query.getResultList();
			if ( guests.size() > 0 ) guest = guests.get(0);
		}
		return guest;
    }
}